#!/bin/bash
#Modoboa Amavis Quarantine Digest Mail Sender
#Fatih Usta <fatihusta@labrisnetworks.com> / Labris Networks

_cat=$(which cat)
_sed=$(which sed)
_tr=$(which tr)
_date=$(which date)
_awk=$(which awk)
_sort=$(which sort)
_uniq=$(which uniq)
_rm=$(which rm)
_cut=$(which cut)
_grep=$(which grep)
_dig=$(which dig)
_snail=$(which s-nail)


config=/etc/ahtapot-quarantine-digest.conf

if [ -f $config ];then
    source $config
else
    echo "Config file not found. $config"
    exit 1
fi

if [[ $enable == "no" ]];then
    echo "Digest Mail Disabled"
    exit 0
fi

if [ ! -f $_mail ];then
    echo "s-nail command not found."
    echo "apt install s-nail"
    exit 1
fi

#MYSQL Command
if [ -z "$myport" ];then
    _mysql="/usr/bin/mysql --host=$myhost --user=$myuser --password=$mypasswd $db_name -e"
else
    _mysql="/usr/bin/mysql --host=$myhost --port=$myport --user=$myuser --password=$mypasswd $db_name -e"
fi

mail_template(){
    local rcpt=$1
echo "Content-Type: text/html
MIME-Version: 1.0
"
    html "$($_cat $tmpdir/${rcpt}_quarantine_table)"
}

html(){
    local table="$1"
$_cat <<EOF
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
    <head>
        <meta http-equiv="Content-Type" content="text/html; charset=UTF-8" />
        <title></title>
        <style></style>
    </head>
    <body>
        <br>
	<br>
        $description
	<br>
	<br>
        <style type="text/css">
        .tg  {border-collapse:collapse;border-spacing:0;border-color:#aaa;margin:0px auto;padding:0; margin:0;}
        .tg td{font-family:Arial, sans-serif;font-size:14px;padding:10px 5px;border-style:solid;border-width:0px;overflow:hidden;word-break:normal;border-top-width:1px;border-bottom-width:1px;border-color:#aaa;color:#333;background-color:#fff;}
        .tg th{font-family:Arial, sans-serif;font-size:14px;font-weight:normal;padding:10px 5px;border-style:solid;border-width:0px;overflow:hidden;word-break:normal;border-top-width:1px;border-bottom-width:1px;border-color:#aaa;color:#fff;background-color:#f38630;}
        .tg .tg-k7le{font-weight:bold;font-size:15px;color:#ffffff;border-color:inherit;text-align:center;vertical-align:top}
        .tg .tg-bubk{font-weight:bold;font-size:15px;color:#ffffff;border-color:inherit;text-align:left;vertical-align:top}
        .tg .tg-0pky{border-color:inherit;text-align:left;vertical-align:top}
        .tg .tg-rx0o{background-color:#ffffff;color:#9a0000;text-align:left;vertical-align:top}
        .tg .tg-yaek{background-color:#ffffff;color:#f8a102;text-align:left;vertical-align:top}
        .tg .tg-zvwx{background-color:#ffffff;color:#009901;text-align:left;vertical-align:top}
        </style>
        <table class="tg" style="undefined;table-layout: fixed; width: 1014px">
        <colgroup>
        <col style="width: 231px">
        <col style="width: 300px">
        <col style="width: 483px">
	<col style="width: 150px">
        </colgroup>
          <tr>
            <th class="tg-k7le">Date</th>
            <th class="tg-bubk">From</th>
            <th class="tg-bubk">Subject</th>
            <th class="tg-bubk">Type</th>
          </tr>
	  $table
        </table>
    </body>
</html>
EOF
}

type_convert(){
    case $1 in
	    C) echo "Clean";;
	    S) echo "Spam";;
	    Y) echo "Spammy";;
	    V) echo "Virus";;
	    H) echo "Bad Header";;
	    M) echo "Bad Mime";;
	    B) echo "Banned";;
	    O) echo "Over Sized";;
	    T) echo "MTA Error";;
	    U) echo "Unchecked";;
	    *) echo "$1";;
    esac
}
type_color_convert(){
    red=tg-rx0o
    yellow=tg-yaek
    green=tg-zvwx
    black=tg-0pky

    case $1 in
	    C) echo "$green";;
	    S|V) echo "$red";;
	    U) echo "$black";;
	    *) echo "$yellow";;
    esac
}

sqlquery="SELECT msgs.mail_id,msgs.time_num,msgs.from_addr,recip.email,msgs.subject,msgs.content  FROM msgs   LEFT JOIN msgrcpt ON msgs.mail_id=msgrcpt.mail_id   LEFT JOIN maddr AS sender ON msgs.sid=sender.id   LEFT JOIN maddr AS recip ON msgrcpt.rid=recip.id where msgs.time_num > (UNIX_TIMESTAMP() - $time)"

#Get quarantine mail list
$_mysql "$sqlquery" | $_sed "1d" | $_tr '\t' '|' > $quarantine_list

#List Spam Digest Users
$_cat $quarantine_list | $_awk -F "|" '{print $4}' | $_sort | $_uniq > $digest_users

#Create html table for recipient
$_cat $quarantine_list |\
while read line;
do
    mail_id=$(echo $line | cut -d"|" -f1)
    udate=$(echo $line | cut -d"|" -f2)
    from="$(echo $line | cut -d"|" -f3 |$_sed -e "s/<//" -e "s/>//")"
    rcpt="$(echo $line | cut -d"|" -f4)"
    subject="$(echo $line | cut -d"|" -f5)"
    type=$(echo $line | cut -d"|" -f6)

    #Format unix date (Mon Sep  3 16:20:16 +03 2018 )
    fdate=$($_date -d @$udate)

    #Format human readable type
    ftype=$(type_convert $type)
    type_color=$(type_color_convert $type)

    link="$url/$mail_id/?rcpt=$rcpt"

    if [ -z "$subject" ];then
        subject="No Subject"
    fi
    #echo "$mail_id $fdate $from $rcpt $subject $ftype $link" 
    echo "<tr>
  <td class="tg-0pky">"$fdate"</td>
  <td class="tg-0pky">"$from"</td>
  <td class="tg-0pky"><a href="$link" target="_blank">"$subject"</a></td>
  <td class="$type_color">$ftype</td>
</tr>" >> $tmpdir/${rcpt}_quarantine_table
done

#Send digest mail for recipient
for msgrcpt in $($_cat $digest_users)
do
    #mail $msgrcpt > $tmpdir/$msgrcpt.mail
    mail_template $msgrcpt | ${_snail} -s "$subject" -S smtp=smtp://$smtp_server:$smtp_port -S from="$from_addr" "$msgrcpt"
done

#Clear tmp file
$_rm -f $tmpdir/*_quarantine_table
